@@ -7,13 +7,16 @@ from .models import GalleryPlugin
 
 
 class GalleryPluginForm(forms.ModelForm):
-    model = GalleryPlugin
+
+    class Meta:
+        fields = ['style', 'engine', 'timeout', 'duration', 'shuffle']
+        model = GalleryPlugin
 
     def clean_style(self):
         style = self.cleaned_data.get('style')
         # Check if template for style exists:
         try:
-            select_template(['aldryn_gallery/plugins/%s/gallery.html' % style])
+            select_template(['aldryn_gallery/%s/gallery.html' % style])
         except TemplateDoesNotExist:
             raise forms.ValidationError("Not a valid style (Template does not exist)")
         return style
